`ejudge` is an eletronic judge/grader for code. It can run Python, C, and C++
code in a sandbox and supporting other languages is easy.

This library uses the ``iospec`` format for specifying the expected inputs and
outputs for the some program execution.
